@@ -1,7 +1,10 @@
-from pytest import fixture
+import itertools
+
+from pytest import fixture, mark
 
 from wand.image import Image
 from wand.color import Color
+from wand.compat import nested
 from wand.api import library
 from wand.drawing import Drawing
 
@@ -118,6 +121,27 @@ def test_draw_line(fx_wand):
         assert img[8,5] == Color('#ccc')
 
 
+@mark.parametrize('kwargs', itertools.product(
+    [('right', 40), ('width', 30)],
+    [('bottom', 40), ('height', 30)]
+))
+def test_draw_rectangle(kwargs, display, fx_wand):
+    with nested(Color('#fff'),
+                Color('#333'),
+                Color('#ccc')) as (white, black, gray):
+        with Image(width=50, height=50, background=white) as img:
+            fx_wand.stroke_width = 2
+            fx_wand.fill_color = black
+            fx_wand.stroke_color = gray
+            fx_wand.rectangle(left=10, top=10, **dict(kwargs))
+            fx_wand.draw(img)
+            display(img)
+            assert img[7, 7] == img[7, 42] == img[42, 7] == \
+                   img[42, 42] == img[0, 0] == img[49, 49] == white
+            assert img[12, 12] == img[12, 38] == img[38, 12] == \
+                   img[38, 38] == black
+
+
 def test_draw_text(fx_asset):
     with Color('#fff') as white:
         with Image(width=100, height=100, background=white) as img:
@@ -155,3 +179,15 @@ def test_get_font_metrics_test(fx_asset):
             assert m1.text_width < m2.text_width
             assert m2.text_width > m3.text_width
             assert m2.text_height < m3.text_height
+
+
+def test_regression_issue_163(tmpdir):
+    """https://github.com/dahlia/wand/issues/163"""
+    unicode_char = b'\xce\xa6'.decode('utf-8')
+    with Drawing() as draw:
+        with Image(width=500, height=500) as image:
+            draw.font_size = 20
+            draw.gravity = 'south_west'
+            draw.text(0, 0, unicode_char)
+            draw(image)
+            image.save(filename=str(tmpdir.join('out.jpg')))
