@@ -11,8 +11,9 @@ import ctypes.util
 import itertools
 import os
 import os.path
-import sys
 import platform
+import sys
+import traceback
 
 __all__ = ('MagickPixelPacket', 'c_magick_char_p', 'library', 'libc',
            'libmagick', 'load_library')
@@ -40,7 +41,7 @@ class c_magick_char_p(ctypes.c_char_p):
 
 def find_library(suffix=''):
     """Finds library path to try loading.  The result paths are not
-    guarenteed that they exist.
+    guaranteed that they exist.
 
     :param suffix: optional suffix e.g. ``'-Q16'``
     :type suffix: :class:`basestring`
@@ -141,10 +142,12 @@ except (OSError, IOError):
     elif sys.platform == 'win32':
         msg += '#install-imagemagick-on-windows'
     elif sys.platform == 'darwin':
-        for pkgmgr in 'brew', 'port':
+        mac_pkgmgrs = {'brew': 'brew install freetype imagemagick',
+                       'port': 'port install imagemagick'}
+        for pkgmgr in mac_pkgmgrs:
             with os.popen('which ' + pkgmgr) as f:
                 if f.read().strip():
-                    msg = pkgmgr + ' install imagemagick'
+                    msg = mac_pkgmgrs[pkgmgr]
                     break
         else:
             msg += '#install-imagemagick-on-mac'
@@ -291,6 +294,11 @@ try:
 
     library.MagickSetImageColorspace.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
+    library.MagickGetImageCompression.argtypes = [ctypes.c_void_p]
+    library.MagickGetImageCompression.restype = ctypes.c_int
+
+    library.MagickSetImageCompression.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
     library.MagickGetImageDepth.argtypes = [ctypes.c_void_p]
     library.MagickGetImageDepth.restype = ctypes.c_size_t
 
@@ -315,7 +323,7 @@ try:
 
     library.MagickSampleImage.argtypes = [ctypes.c_void_p, ctypes.c_size_t,
                                           ctypes.c_size_t]
-                                          
+
     library.MagickResizeImage.argtypes = [ctypes.c_void_p, ctypes.c_size_t,
                                           ctypes.c_size_t, ctypes.c_int,
                                           ctypes.c_double]
@@ -619,10 +627,10 @@ try:
     library.DrawSetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
-    library.DrawSetStrokeColor.argtypes = [ctypes.c_void_p, 
+    library.DrawSetStrokeColor.argtypes = [ctypes.c_void_p,
                                            ctypes.c_void_p]
 
-    library.DrawSetStrokeWidth.argtypes = [ctypes.c_void_p, 
+    library.DrawSetStrokeWidth.argtypes = [ctypes.c_void_p,
                                            ctypes.c_double]
 
     library.DrawSetTextAlignment.argtypes = [ctypes.c_void_p,
@@ -655,7 +663,7 @@ try:
     library.DrawGetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
-    library.DrawGetStrokeColor.argtypes = [ctypes.c_void_p, 
+    library.DrawGetStrokeColor.argtypes = [ctypes.c_void_p,
                                            ctypes.c_void_p]
 
     library.DrawGetStrokeWidth.argtypes = [ctypes.c_void_p]
@@ -720,11 +728,23 @@ try:
                                  ctypes.c_double,
                                  ctypes.c_double]
 
+    library.DrawRectangle.argtypes = [ctypes.c_void_p,
+                                      ctypes.c_double,
+                                      ctypes.c_double,
+                                      ctypes.c_double,
+                                      ctypes.c_double]
+
     library.DrawAnnotation.argtypes = [ctypes.c_void_p,
                                        ctypes.c_double,
                                        ctypes.c_double,
                                        ctypes.POINTER(ctypes.c_ubyte)]
 
+    library.MagickNegateImage.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
+    library.MagickNegateImageChannel.argtypes = [ctypes.c_void_p,
+                                                 ctypes.c_int,
+                                                 ctypes.c_int]
+
     library.MagickNormalizeImage.argtypes = [ctypes.c_void_p]
 
     library.MagickNormalizeImageChannel.argtypes = [ctypes.c_void_p,
@@ -741,8 +761,15 @@ try:
     library.MagickQueryMultilineFontMetrics.restype = ctypes.POINTER(
         ctypes.c_double
     )
+
+    library.MagickModulateImage.argtypes = [ctypes.c_void_p,
+                                            ctypes.c_double,
+                                            ctypes.c_double,
+                                            ctypes.c_double]
 except AttributeError:
-    raise ImportError('MagickWand shared library not found or incompatible')
+    raise ImportError('MagickWand shared library not found or incompatible\n'
+                      'Original exception was raised in:\n' +
+                      traceback.format_exc())
 
 #: (:class:`ctypes.CDLL`) The C standard library.
 libc = None
