@@ -10,6 +10,7 @@ import ctypes
 import warnings
 
 from .api import library
+from .compat import string_type
 from .exceptions import TYPE_MAP, WandException
 
 
@@ -207,7 +208,10 @@ class Resource(object):
             return
         self.c_clear_exception(self.wand)
         exc_cls = TYPE_MAP[severity.value]
-        return exc_cls(desc.value)
+        message = desc.value
+        if not isinstance(message, string_type):
+            message = message.decode()
+        return exc_cls(message)
 
     def raise_exception(self, stacklevel=1):
         """Raises an exception or warning if it has occurred."""
